@@ -7,6 +7,7 @@ import Control.Arrow (Kleisli)
 import Data.Profunctor (Forget, Star, Strong)
 import Fresnel.Iso.Internal (IsIso)
 import Fresnel.Profunctor.OptionalStar (OptionalStar)
+import Fresnel.Profunctor.Star1 (Star1)
 
 class (IsIso p, Strong p) => IsLens p
 
@@ -14,4 +15,5 @@ instance IsLens (->)
 instance Monad m => IsLens (Kleisli m)
 instance IsLens (Forget r)
 instance Functor f => IsLens (Star f)
+instance Functor f => IsLens (Star1 f)
 instance Functor f => IsLens (OptionalStar f)
