@@ -23,9 +23,9 @@ withRoundtrips :: Iso' s a -> (((s -> s) -> (a -> a) -> r) -> r)
 withRoundtrips o k = withIso o (\ f g -> k (g . f) (f . g))
 
 
-prop_view_elimination f g x = view (iso (applyFun f) (applyFun g)) x === applyFun f x
+prop_view_elimination (Fn f) (Fn g) x = view (iso f g) x === f x
 
-prop_review_elimination f g x = review (iso (applyFun f) (applyFun g)) x === applyFun g x
+prop_review_elimination (Fn f) (Fn g) x = review (iso f g) x === g x
 
 
 prop_constant_validity c s a = withRoundtrips (constant c) $ \ sasa aa ->
