@@ -6,7 +6,7 @@ import Fresnel.Review
 import Test.Group
 import Test.QuickCheck
 
-prop_review_unto_involution f x = review (unto (applyFun f)) x === applyFun f x
+prop_review_unto_involution (Fn f) x = review (unto f) x === f x
 
 
 pure []
